/*
 * A recap of the rules:
 * 1) You can use a static variable in a non-static method (like how we use a static counter for assigning account id's).
 * 2) You cannot use a non-static variable in a static method (like how cannot use a non-static branchName of Bank in a static method).
 * Principles:
 * A. To use a non-static variable or non-static method, we must create a context object.
 * B. To use a static variable or static method, we can JUST use the class name 
 * (but, using a context object to access a static variable or static method is also fine, but it'd give us a warning.) 
 */

class MyClass {
    /* this is a non-static attribute, specific to each instance  */
    int i;
    /* this is a static attribute, global to all instances */
    static int si = 2;
   
    /* There is no compilation error for this method. */
    void changeOne () { // a non-static method requires a context object
        /* OK: i being a non-static variable CAN be accessed through the context object this */
        i ++; // same as writing this.i ++;
        /* OK: si being a static variable CAN be accessed through the context object this */
        si ++; // same as writing this.si ++;
    }

    /* There is a compilation error for this method. */
    static void changeTwo () { // a static method may be called using the class name
        /* Error: i being a non-static variable requires a context object,
           but changeTwo() may be called via the class name: MyClass.changeTwo() */
        i ++;
        /* OK: i being a static variable can be accessed via the class name: MyClass.si */
        si ++;
    }
}
